@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2012 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
  *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,7 +20,7 @@ AddTagDialog::AddTagDialog(QWidget *parent)
 setModal(true);
 ui.setupUi(this);
 QPixmap pixmap1, pixmap2;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+
 if (qApp->devicePixelRatio()>=2)
   {
   pixmap1.load(":/images/trigger@2x.png");
@@ -33,10 +33,7 @@ else
   pixmap1.load(":/images/trigger.png");
   pixmap2.load(":/images/triggerbis.png");
   }
-#else
-  pixmap1.load(":/images/trigger.png");
-  pixmap2.load(":/images/triggerbis.png");
-#endif
+
 ui.label_4->setPixmap(pixmap1);
 ui.label_5->setPixmap(pixmap2);
 }
