@@ -258,15 +258,16 @@ while (i < text.length())
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
 			state=StateStandard;
+
 			int poslab=buffer.indexOf("label{");
 			if (poslab!=-1)
 			  {
-			  for (k=poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
+			  for (k=i-buffer.length()+poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			  }
 			poslab=buffer.indexOf("cite{");
 			if (poslab!=-1)
 			  {
-			  for (k=poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
+			  for (k=i-buffer.length()+poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			  }
 			poslab=buffer.indexOf("begin{verbatim}");
 			if(poslab != -1) {state=StateVerbatim;for (k=poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}}
