@@ -1,13 +1,14 @@
-/****************************************************************************
-**
-**   copyright       : (C) 2003-2012 by Pascal Brachet                     
-**   http://www.xm1math.net/texmaker/                                      
-**
-** Parts of this file come from Texworks (GPL) Copyright (C) 2007-2010  Jonathan Kew
-**
-**
-****************************************************************************/
- 
+/***************************************************************************
+ *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
+
 #include "pdfviewer.h"
 
 #include <QtGui>
@@ -30,18 +31,8 @@
 #include <QDesktopWidget>
 
 #include "geticon.h"
+#include "theme.h"
 
-#if defined(POPPLER20)
-#include "texmaker_popplerqt20/poppler-qt4.h"
-#elif defined(POPPLER22)
-#include "texmaker_popplerqt22/poppler-qt4.h"
-#elif defined(POPPLER24EMB)
-#include "texmaker_popplerqt5_24/poppler-qt5.h"
-#elif defined(POPPLER24)
-#include <poppler-qt5.h>
-#else
-#include <poppler-qt4.h>
-#endif
 
 #define SYNCTEX_GZ_EXT ".synctex.gz"
 #define SYNCTEX_EXT ".synctex"
@@ -88,8 +79,8 @@ lastScale=startScale;
 fileLoaded=false;
 currentPage=1;
 
-doc = 0;
-searchleft=0.0; searchtop=0.0; searchright=0.0; searchbottom=0.0;
+
+lastSearchPos=-1;
 scanner=NULL;
 path= QPainterPath();
 
@@ -115,6 +106,11 @@ LeftPanelToolBar->setIconSize(QSize(16,16 ));
 LeftPanelStackedWidget=new QStackedWidget(StructureView);
 
 listpagesWidget=new QListWidget(LeftPanelStackedWidget);
+listpagesWidget->setFrameShape(QFrame::NoFrame);
+listpagesWidget->setFrameShadow(QFrame::Plain);
+listpagesWidget->viewport()->setStyleSheet(Theme::viewportDarkStyleSheet);
+listpagesWidget->setStyleSheet(Theme::listwidgetStyleSheet);
+listpagesWidget->setLineWidth(0);
 
 connect(LeftPanelToolBar->addAction(getIcon(":/images/pages.png"),tr("Pages")), SIGNAL(triggered()), this, SLOT(ShowListPages()));
 LeftPanelStackedWidget->addWidget(listpagesWidget);
@@ -125,14 +121,14 @@ StructureTreeView=new QTreeView(LeftPanelStackedWidget);
 StructureTreeView->header()->hide();
 StructureTreeView->setEditTriggers(QAbstractItemView::NoEditTriggers);
 StructureTreeView->header()->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+
 StructureTreeView->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
-#else
-StructureTreeView->header()->setResizeMode(0, QHeaderView::ResizeToContents);
-#endif
+
 StructureTreeView->header()->setStretchLastSection(false);
 StructureTreeView->setIndentation(15);
 StructureTreeView->setModel(0);
+StructureTreeView->viewport()->setStyleSheet(Theme::viewportDarkStyleSheet);
+StructureTreeView->setStyleSheet(Theme::treeviewStyleSheet);
 
 
 connect(LeftPanelToolBar->addAction(getIcon(":/images/structure.png"),tr("Structure")), SIGNAL(triggered()), this, SLOT(ShowStructure()));
@@ -181,6 +177,7 @@ editMenu->addAction(findAct);
 
 QToolBar *toolBar = addToolBar("Pdf controls");
 toolBar->setObjectName("Pdf controls");
+toolBar->setStyleSheet(Theme::toolbarlightStyleSheet);
 
 upAct = new QAction(getIcon(":/images/up.png"), tr("Previous"), this);
 upAct->setShortcut(QKeySequence::MoveToPreviousPage);
@@ -258,11 +255,13 @@ scaleComboBox->addItems(scalePercents);
 scaleComboBox->setCurrentIndex(3);
 scaleComboBox->setEditable(true);
 scaleComboBox->setLineEdit(zoomCustom);
+scaleComboBox->setStyleSheet(Theme::comboboxStyleSheet);
 toolBar->addWidget(scaleComboBox);
 
 toolBar->addSeparator();
 
 searchLineEdit = new QLineEdit(toolBar);
+searchLineEdit->setStyleSheet(Theme::lineeditStyleSheet);
 toolBar->addWidget(searchLineEdit);
 
 searchAct=new QAction(getIcon(":/images/pdffind.png"), tr("Find"), this);
@@ -282,8 +281,7 @@ toolBar->addAction(printAct);
 externAct = new QAction(getIcon(":/images/viewpdf.png"), tr("External Viewer"), this);
 toolBar->addAction(externAct);
 
-checkerAct = new QAction(getIcon(":/images/pdfchecker.png"), tr("Check Spelling and Grammar on this page"), this);
-toolBar->addAction(checkerAct);
+
 
 searchLineEdit->setEnabled(false);
 searchAct->setEnabled(false);
@@ -351,13 +349,11 @@ if (scanner != NULL)
 synctex_scanner_free(scanner);
 scanner = NULL;
 }
+
 if (pdfview->open(fn)) 
   {
   listpagesWidget->clear();
-  doc=pdfview->doc();
-  doc->setRenderHint(Poppler::Document::Antialiasing);
-  doc->setRenderHint(Poppler::Document::TextAntialiasing);
-  searchLocation = QRectF();
+  lastSearchPos=-1;
   searchLineEdit->setEnabled(true);
   searchAct->setEnabled(true);
   //findButton->setEnabled(true);
@@ -381,7 +377,7 @@ if (pdfview->open(fn))
   StructureTreeView->setModel(pdfview->outlineModel());
   QString syncFile = QFileInfo(fn).canonicalFilePath();
   scanner = synctex_scanner_new_with_output_file(syncFile.toUtf8().data(), NULL, 1);
-  if ((fn==lastFile) && (lpage <= doc->numPages()) && (lpage>0))
+  if ((fn==lastFile) && (lpage <= pdfview->doc()->pageCount()) && (lpage>0))
     {
     currentPage=lpage;
     currentScale=lscale;
@@ -406,7 +402,7 @@ if (pdfview->open(fn))
     currentScale=pdfview->realScale();
     zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
     }
-  for (int i = 0; i < doc->numPages(); ++i)
+  for (int i = 0; i < pdfview->doc()->pageCount(); ++i)
     {
     listpagesWidget->addItem(tr("Page")+" "+QString::number(i+1)); 
     }
@@ -473,7 +469,6 @@ connect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 connect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 connect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 connect(externAct, SIGNAL(triggered()), this, SLOT(runExternalViewer()));
-connect(checkerAct, SIGNAL(triggered()), this, SLOT(checkSpellGrammarPage()));
 connect(pdfview, SIGNAL(currentPageChanged(int)), this, SLOT(checkPage(int)));
 connect(pdfview, SIGNAL(gotoDest(int,qreal,qreal)), this, SLOT(jumpToDest(int,qreal,qreal)));
 connect(pdfview, SIGNAL(syncpage(int, const QPointF&)), this, SLOT(jumpToEditor(int, const QPointF&)));
@@ -513,7 +508,6 @@ disconnect(historyBackAct, SIGNAL(triggered()), this, SLOT(historyBack()));
 disconnect(historyForwardAct, SIGNAL(triggered()), this, SLOT(historyForward()));
 disconnect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 disconnect(externAct, SIGNAL(triggered()), this, SLOT(runExternalViewer()));
-disconnect(checkerAct, SIGNAL(triggered()), this, SLOT(checkSpellGrammarPage()));
 disconnect(pdfview, SIGNAL(currentPageChanged(int)), this, SLOT(checkPage(int)));
 disconnect(pdfview, SIGNAL(gotoDest(int,qreal,qreal)), this, SLOT(jumpToDest(int,qreal,qreal)));
 disconnect(pdfview, SIGNAL(syncpage(int, const QPointF&)), this, SLOT(jumpToEditor(int, const QPointF&)));
@@ -531,7 +525,7 @@ disconnect(presentationAction, SIGNAL(triggered()),this, SLOT(on_presentation_tr
 //disconnect( this, SIGNAL( forwardAvailable( bool ) ), historyForwardAct, SLOT( setEnabled( bool ) ) );
 }
 
-void PdfViewer::jumpToPdfFromSource(QString sourceFile, int source_line)
+void PdfViewer::jumpToPdfFromSource(QString sourceFile, int source_line, int source_col)
 {
 show();
 if (windowState()==Qt::WindowMinimized) setWindowState(windowState() & ~Qt::WindowMinimized | Qt::WindowActive);
@@ -605,7 +599,7 @@ pdfview->setHighlightPath(currentPage-1,path);
 void PdfViewer::gotoPage(int page)
 {
 if (!fileLoaded) return;
-if ((page <= doc->numPages()) && (page>=1))
+if ((page <= pdfview->doc()->pageCount()) && (page>=1))
   {
   currentPage=page;
   lastPage=currentPage;
@@ -630,7 +624,7 @@ void PdfViewer::updateCurrentPage()
 if (!fileLoaded) return;
 if (currentPage==1) upAct->setEnabled(false);
 else upAct->setEnabled(true);
-if (currentPage==doc->numPages()) downAct->setEnabled(false);
+if (currentPage==pdfview->doc()->pageCount()) downAct->setEnabled(false);
 else downAct->setEnabled(true);
 QList<QListWidgetItem *> fItems=listpagesWidget->findItems (tr("Page")+" "+QString::number(currentPage),Qt::MatchRecursive);
 if ((fItems.size()>0 ) && (fItems.at(0))) listpagesWidget->setCurrentItem(fItems.at(0));
@@ -639,7 +633,7 @@ if ((fItems.size()>0 ) && (fItems.at(0))) listpagesWidget->setCurrentItem(fItems
 void PdfViewer::jumpToDest(int page,qreal left, qreal top)
 {
 if (!fileLoaded) return;
-if ((page <= doc->numPages()) && (page>=1))
+if ((page <= pdfview->doc()->pageCount()) && (page>=1))
   {
   currentPage=page;
   lastPage=currentPage;
@@ -710,7 +704,7 @@ connect(pdfview, SIGNAL(currentPageChanged(int)), this, SLOT(checkPage(int)));
         QList<QRectF> locations;
         searchLocation = QRectF();
 
-        while (doc->page(page)->search(text, searchLocation,
+        while (pdfview->doc()->page(page)->search(text, searchLocation,
             Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) {
 
             if (searchLocation != oldLocation)
@@ -734,18 +728,18 @@ connect(pdfview, SIGNAL(currentPageChanged(int)), this, SLOT(checkPage(int)));
         page -= 1;
     }
 
-    if (currentPage == doc->numPages() - 1)
+    if (currentPage == pdfview->doc()->pageCount() - 1)
         return QRectF();
 
     oldLocation = QRectF();
-    page = doc->numPages() - 1;
+    page = pdfview->doc()->pageCount() - 1;
 
     while (page > currentPage) {
 
         QList<QRectF> locations;
         searchLocation = QRectF();
 
-        while (doc->page(page)->search(text, searchLocation,
+        while (pdfview->doc()->page(page)->search(text, searchLocation,
             Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) {
 
             locations.append(searchLocation);
@@ -765,23 +759,21 @@ connect(pdfview, SIGNAL(currentPageChanged(int)), this, SLOT(checkPage(int)));
 void PdfViewer::searchForwards(const QString &text)
 {
 int page = currentPage-1;
-while (page < doc->numPages()) 
+
+
+while (page < pdfview->doc()->pageCount()) 
   {
 
   if (currentPage>=1) 
     {
     pdfview->clearPaths(currentPage-1);  
     }
-  if (doc->page(page)->search(text, searchleft, searchtop, searchright, searchbottom, Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) 
-    {
-    searchLocation.setLeft(searchleft);
-    searchLocation.setTop(searchtop);
-    searchLocation.setRight(searchright);
-    searchLocation.setBottom(searchbottom);
-    if (!searchLocation.isNull()) 
+    findItem searchItem =pdfview->doc()->find(page, text, lastSearchPos);
+  if (!searchItem.rect.isNull()) 
       {
+      lastSearchPos=searchItem.pos;
       path= QPainterPath();
-      path.addRect(searchLocation);
+      path.addRect(searchItem.rect);
       QRectF r = path.boundingRect();
       currentPage=page+1;
       lastPage=currentPage;
@@ -791,9 +783,8 @@ while (page < doc->numPages())
       updateCurrentPage();
       return;
       }
-    }
     page += 1;
-    searchLocation = QRectF();
+    lastSearchPos=-1;
   }
 page = 0;
 while (page < currentPage-1) 
@@ -802,17 +793,13 @@ while (page < currentPage-1)
     {
     pdfview->clearPaths(currentPage-1);    
     }
-  searchLocation = QRectF();
-  if (doc->page(page)->search(text, searchleft, searchtop, searchright, searchbottom, Poppler::Page::NextResult, Poppler::Page::CaseInsensitive)) 
-    {
-    searchLocation.setLeft(searchleft);
-    searchLocation.setTop(searchtop);
-    searchLocation.setRight(searchright);
-    searchLocation.setBottom(searchbottom);
-    if (!searchLocation.isNull()) 
+lastSearchPos=-1;
+findItem searchItem =pdfview->doc()->find(page, text,lastSearchPos);
+  if (!searchItem.rect.isNull()) 
       {
+      lastSearchPos=searchItem.pos;
       path= QPainterPath();
-      path.addRect(searchLocation);
+      path.addRect(searchItem.rect);
       QRectF r = path.boundingRect();
       currentPage=page+1;
       lastPage=currentPage;
@@ -822,7 +809,6 @@ while (page < currentPage-1)
       updateCurrentPage();
       return;
       }
-    }
   page += 1;
   }
 }
@@ -846,7 +832,7 @@ if (currentPage>1)
 void PdfViewer::pageDown()
 {
 if (!fileLoaded) return;
-if (currentPage<doc->numPages())
+if (currentPage<pdfview->doc()->pageCount())
   {
   currentPage++;
   lastPage=currentPage;
@@ -938,106 +924,6 @@ if (fi.exists())
 	}
 }
 
-void PdfViewer::checkSpellGrammarPage()
-{
-if (!fileLoaded) return;
-if ((currentPage<1) || (currentPage>doc->numPages())) return;
-QString tempDir=QDir::tempPath();
-QString prefixFile=QDir::homePath();
-prefixFile="texmaker_temp_"+prefixFile.section('/',-1);
-prefixFile=QString(QUrl::toPercentEncoding(prefixFile));
-prefixFile.remove("%");
-QString tempFile=tempDir+"/"+prefixFile+".html";
-QTextCodec *codec = QTextCodec::codecForName("UTF-8");
-#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-#ifdef USB_VERSION
-QString atdloc=QCoreApplication::applicationDirPath()+"/";
-#else
-QString atdloc=PREFIX"/share/texmaker/";
-#endif
-#endif
-#if defined(Q_OS_MAC)
-QString atdloc=QCoreApplication::applicationDirPath() + "/../Resources/";
-#endif
-#if defined(Q_OS_WIN32)
-QString atdloc=QCoreApplication::applicationDirPath() + "/";
-#endif
-QString pdf_text=doc->page(currentPage-1)->text(QRectF(),Poppler::Page::PhysicalLayout);
-QFile fi_html(tempFile);
-if (!fi_html.open(QIODevice::WriteOnly)) return;
-QTextStream out (&fi_html);
-out.setCodec(codec);
-out << "<html>\n";
-out << "<head>\n";
-out << "<title>Texmaker</title>\n";
-out << "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n";
-out << "<style>\n";
-out << ".input\n";
-out << "{\n";
-out << "width:90%;\n";
-out << "height:90%;\n";
-out << "border: 1px solid black;\n";
-out << "padding: 2px;\n";
-out << "margin: 2px;\n";
-out << "font-family: times;\n";
-out << "font-size: 80%;\n";
-out << "}\n";
-out << "</style>\n";
-out << "<script src=\"http://code.jquery.com/jquery-1.4.2.js\"></script>\n";
-out << "<script src=\"";
-out << atdloc;
-out << "/jquery.atd.textarea.js\"></script>\n";
-out << "<script src=\"";
-out << atdloc;
-out << "/csshttprequest.js\"></script>\n";
-out << "<link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"";
-out << atdloc;
-out << "/atd.css\" />\n";
-out << "<script>\n";
-out << "function check() {\n";
-out << "AtD.rpc_css_lang = document.langform.langchoice.options[document.langform.langchoice.selectedIndex].text;\n";
-//out << atd_lang;
-//out << "';\n";
-out << "AtD.checkTextAreaCrossAJAX('textInput', 'checkLink', 'Click to reset');\n";
-out << " };\n";
-out << "</script>\n";
-out << "</head>\n";
-out << "<body BGCOLOR=\"#ffffff\">\n";
-out << "<textarea name=\"textInput\" id=\"textInput\" class=\"input\">\n";
-out << pdf_text;
-out << "</textarea>\n";
-out << "<form name=\"langform\">\n";
-out << "<p><a href=\"javascript:check()\" id=\"checkLink\">Click to check</a>&nbsp;&nbsp;\n";
-out << "<SELECT NAME=\"langchoice\">\n";
-bool done=false;
-if (spell_lang=="fr") {out << "<OPTION selected>fr</OPTION>\n"; done=true;}
-else out << "<OPTION>fr</OPTION>\n";
-if (spell_lang=="de") {out << "<OPTION selected>de</OPTION>\n"; done=true;}
-else out << "<OPTION>de</OPTION>\n";
-if (spell_lang=="nl") {out << "<OPTION selected>nl</OPTION>\n"; done=true;}
-else out << "<OPTION>nl</OPTION>\n";
-if (spell_lang=="pl") {out << "<OPTION selected>pl</OPTION>\n"; done=true;}
-else out << "<OPTION>pl</OPTION>\n";
-if (spell_lang=="pt") {out << "<OPTION selected>pt</OPTION>\n"; done=true;}
-else out << "<OPTION>pt</OPTION>\n";
-if (spell_lang=="ru") {out << "<OPTION selected>ru</OPTION>\n"; done=true;}
-else out << "<OPTION>ru</OPTION>\n";
-if (spell_lang=="it") {out << "<OPTION selected>it</OPTION>\n"; done=true;}
-else out << "<OPTION>it</OPTION>\n";
-if (spell_lang=="es") {out << "<OPTION selected>es</OPTION>\n"; done=true;}
-else out << "<OPTION>es</OPTION>\n";
-if ((spell_lang=="en") || (!done)) out << "<OPTION selected>en</OPTION>\n";
-else out << "<OPTION>en</OPTION>\n";
-out << "</SELECT></p></form>\n";
-out << "</body>\n";
-out << "</html>\n";
-fi_html.close();
-if (browserWindow) browserWindow->close();
-browserWindow=new Browser("file:///"+tempFile,false, 0);
-browserWindow->raise();
-browserWindow->show();
-
-}
 
 
 
@@ -1052,8 +938,8 @@ unsigned int firstPage, lastPage;
 QPrinter printer(QPrinter::HighResolution);
 QPrintDialog printDlg(&printer, this);
 printer.setDocName(fi.baseName());
-printDlg.setMinMax(1, doc->numPages());
-printDlg.setFromTo(1, doc->numPages());
+printDlg.setMinMax(1, pdfview->doc()->pageCount());
+printDlg.setFromTo(1, pdfview->doc()->pageCount());
 printDlg.setOption(QAbstractPrintDialog::PrintToFile, false);
 printDlg.setOption(QAbstractPrintDialog::PrintSelection, false);
 printDlg.setOption(QAbstractPrintDialog::PrintPageRange, true);
@@ -1069,7 +955,7 @@ switch(printDlg.printRange())
 	  break;
   default:
 	  firstPage = 1;
-	  lastPage = doc->numPages();
+	  lastPage = pdfview->doc()->pageCount();
   }
 
 //if(!printer.printerName().isEmpty()) 
@@ -1191,18 +1077,41 @@ StructureView->setWindowTitle(tr("Pages"));
 void PdfViewer::ClickedOnStructure(const QModelIndex& index)
 {
 if (!fileLoaded) return;
-bool ok = false;
-int page = StructureTreeView->model()->data(index, Qt::UserRole + 1).toInt(&ok);
-qreal left = StructureTreeView->model()->data(index, Qt::UserRole + 2).toReal();
-qreal top = StructureTreeView->model()->data(index, Qt::UserRole + 3).toReal();
-qreal destLeft=StructureTreeView->model()->data(index, Qt::UserRole + 4).toReal();
-qreal destTop=StructureTreeView->model()->data(index, Qt::UserRole + 5).toReal();
-if(ok) 
-  {
-  jumpToDest(page, left, top);
+if (!index.isValid()) return;
 
-  jumpToEditor(page-1,QPointF(destLeft,destTop));
-  }
+int page = index.data(QPdfBookmarkModel::PageNumberRole).toInt()+1;
+        qreal left = 0.0;
+        qreal top = 0.0;
+	qreal destLeft=0;
+	qreal destTop=0;
+        page = page >= 1 ? page : 1;
+        page = page <= pdfview->doc()->pageCount() ? page : pdfview->doc()->pageCount();
+
+//         if(linkDestination->isChangeLeft())
+//         {
+//             left = linkDestination->left();
+// 	    destLeft = left * m_document->page(page-1)->pageSizeF().width();
+//             left = left >= 0.0 ? left : 0.0;
+//             left = left <= 1.0 ? left : 1.0;
+//         }
+// 
+//         if(linkDestination->isChangeTop())
+//         {
+//             top = linkDestination->top();
+// 	    destTop = top  * m_document->page(page-1)->pageSizeF().height();
+//             top = top >= 0.0 ? top : 0.0;
+//             top = top <= 1.0 ? top : 1.0;
+//         }
+// int page = StructureTreeView->model()->data(index, Qt::UserRole + 1).toInt(&ok);
+// qreal left = StructureTreeView->model()->data(index, Qt::UserRole + 2).toReal();
+// qreal top = StructureTreeView->model()->data(index, Qt::UserRole + 3).toReal();
+// qreal destLeft=StructureTreeView->model()->data(index, Qt::UserRole + 4).toReal();
+// qreal destTop=StructureTreeView->model()->data(index, Qt::UserRole + 5).toReal();
+// if(ok) 
+//   {
+   jumpToDest(page, left, top);
+// 
+   jumpToEditor(page-1,QPointF(destLeft,destTop));
 }
 
 void PdfViewer::historyBack()
