@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2013 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
  *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,7 @@ labelImage->setMinimumSize(461,696);
 labelImage->setMaximumSize(461,696);
 ui.scrollArea->setMinimumWidth(500);
 ui.scrollArea->setMaximumWidth(500);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+
 if (qApp->devicePixelRatio()>=2)
 {
 labelImage->setMinimumSize(240,348);
@@ -34,7 +34,7 @@ labelImage->setMaximumSize(240,348);
 ui.scrollArea->setMinimumWidth(280);
 ui.scrollArea->setMaximumWidth(280);
 }
-#endif
+
 ui.scrollArea->setBackgroundRole(QPalette::Dark);
 ui.scrollArea->setWidget(labelImage);
 }
@@ -129,9 +129,9 @@ void QuickBeamerDialog::updatePreview(const QString &theme)
 {
 QPixmap pixmap;
 pixmap.load(":/images/beamer/"+theme+".png");
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
+
 if (qApp->devicePixelRatio()>=2) pixmap.setDevicePixelRatio(qApp->devicePixelRatio());
-#endif
+
 labelImage->setPixmap(pixmap);
 }
 
