@@ -40,6 +40,7 @@
 #include <QToolButton>
 #include <QTimer>
 #include <QKeySequence>
+#include <QWidgetAction>
 
 #include "latexeditorview.h"
 #include "minisplitter.h"
@@ -65,6 +66,16 @@ typedef  QMap<QString,QString> KeysMap;
 typedef  QString Userlist[10];
 typedef  QString UserCd[5];
 typedef int SymbolList[412];
+typedef QString foldlist[5];
+const foldlist foldClasses=
+{
+"\\part",
+"\\chapter",
+"\\section",
+"\\subsection",
+"\\subsubsection"
+};
+
 
 class Texmaker : public QMainWindow
 {
@@ -133,6 +144,9 @@ QTableWidget *OutputTableWidget;
 QMenu *fileMenu, *recentMenu, *editMenu, *toolMenu, *sessionMenu;
 QMenu *latex1Menu, *latex11Menu, *latex12Menu, *latex13Menu, *latex14Menu, *latex15Menu, *latex16Menu, *latex17Menu, *latex18Menu ;
 QMenu *math1Menu, *math11Menu, *math12Menu, *math13Menu, *math14Menu;
+
+QMenu *foldMenu, *unfoldMenu;
+
 QMenu *wizardMenu;
 QMenu *bibMenu, *bibtexMenu, *biblatexMenu;
 QMenu *user1Menu, *user11Menu, *user12Menu;
@@ -142,7 +156,8 @@ QMenu *helpMenu;
 QMenu *sectionMenu, *sizeMenu, *refMenu;
 
 QToolBar *fileToolBar, *editToolBar, *runToolBar, /* *formatToolBar ,*/ *logToolBar, *LeftPanelToolBar,*LeftPanelToolBarBis, *centralToolBar, *centralToolBarBis;
-QAction *recentFileActs[10], *ToggleAct, *StopAct, *UndoAct, *RedoAct, *SaveAct, *CutAct, *CopyAct,*PasteAct, *ToggleDocAct, *ViewStructurePanelAct, *ViewLogPanelAct, *ViewPdfPanelAct, *ViewSourcePanelAct, *FullScreenAct, *NextDocAct, *PrevDocAct, *ViewOpenedFilesPanelAct ;
+QAction *recentFileActs[10];
+QAction *ToggleAct, *StopAct, *UndoAct, *RedoAct, *SaveAct, *CutAct, *CopyAct,*PasteAct, *ToggleDocAct, *ViewStructurePanelAct, *ViewLogPanelAct, *ViewPdfPanelAct, *ViewSourcePanelAct, *FullScreenAct, *NextDocAct, *PrevDocAct, *ViewOpenedFilesPanelAct ;
 
 QAction *relationAct, *arrowAct, *miscAct, *delimAct, *greekAct, *usedAct, *favAct, *leftrightAct, *pstricksAct, *mpAct, *tikzAct, *asyAct, *userpanelAct;
 bool showPstricks, showMp, showTikz, showAsy;
@@ -275,6 +290,16 @@ void editTipTab();
 void editRunScript();
 void editRunFurnishedScript();
 
+
+void doFoldAll(int i);
+void doUnfoldAll(int i);
+void foldAll();
+void unfoldAll();
+void foldAllUnder();
+void unfoldAllUnder();
+void foldEnclosing();
+void unfoldEnclosing();
+
 void ReadSettings();
 void SaveSettings();
 void DeleteSettings();
